@@ -2,12 +2,12 @@
 	<context>
 		<name>policy</name>
 		<message>
-			<location filename="com.deepin.diskmanager!message" line="0"/>
+			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
 			<source>Authentication is required to read disk information</source>
 			<translation>Për të lexuar të dhëna disku lypset mirëfilltësim</translation>
 		</message>
 		<message>
-			<location filename="com.deepin.diskmanager!description" line="0"/>
+			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
 			<source>Run Disk Manager Need Authentication</source>
 			<translation>Xhirimi i Përgjegjësit të Disqeve Lyp Mirëfilltësim</translation>
 		</message>
