@@ -38,6 +38,7 @@ void FormateDialog::initUi()
     LUKSFlag luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
     bool isSystemDevice = false;
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        qDebug() << "Current level is PARTITION.";
         PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
         m_pathInfo = info.m_path;
         fileSystemType = info.m_fileSystemType;
@@ -47,6 +48,7 @@ void FormateDialog::initUi()
         luksFlag = info.m_luksFlag;
         isSystemDevice = DMDbusHandler::instance()->getIsSystemDisk(info.m_devicePath);
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+        qDebug() << "Current level is DISK.";
         DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
         m_pathInfo = info.m_path;
         m_curDiskMediaType = info.m_mediaType;
@@ -54,6 +56,7 @@ void FormateDialog::initUi()
         luksFlag = info.m_luksFlag;
         isSystemDevice = DMDbusHandler::instance()->getIsSystemDisk(info.m_path);
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Current level is LOGICALVOLUME.";
         m_height = 315;
         setFixedSize(450, m_height);
         LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
@@ -103,8 +106,10 @@ void FormateDialog::initUi()
 #endif
     m_fileNameEdit->lineEdit()->setValidator(validator );
     m_fileNameEdit->setFixedHeight(36);
-    if (m_fileNameEdit->text().isEmpty())
+    if (m_fileNameEdit->text().isEmpty()) {
+        qDebug() << "File name edit is empty, setting placeholder text.";
         m_fileNameEdit->lineEdit()->setPlaceholderText(tr("Name"));
+    }
 
     DLabel *formatName = new DLabel(tr("File system:"), this);
     formatName->setFont(fontTip);
@@ -118,6 +123,7 @@ void FormateDialog::initUi()
     fslist.removeOne("linux-swap");
 //    QStringList formateList = fslist;
     if (size > 100 && !isSystemDevice && DMDbusHandler::instance()->getCurLevel() != DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Size is greater than 100, not system device, and not logical volume. Getting encryption formats.";
         fslist = DMDbusHandler::instance()->getEncryptionFormate(fslist);
     }
 
@@ -127,29 +133,37 @@ void FormateDialog::initUi()
     QString fsTypeName = Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType));
     // 判断当前设备是否加密
     if (luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+        qDebug() << "LUKS flag is IS_CRYPT_LUKS, checking LUKS info.";
         LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(m_pathInfo);
         // 加密设备是否打开，打开格式设为加密格式，未打开默认设为ext4
         if (luksInfo.isDecrypt) {
+            qDebug() << "LUKS device is decrypted.";
             fileSystemType = luksInfo.m_mapper.m_luksFs;
             if (-1 == fslist.indexOf(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType)))) {
+                qDebug() << "Decrypted file system type not in list, setting to EXT4.";
                 fsTypeName = Utils::fileSystemTypeToString(FSType::FS_EXT4);
             } else {
                 if (luksInfo.m_crypt == CRYPT_CIPHER::AES_XTS_PLAIN64) {
+                    qDebug() << "LUKS encryption is AES_XTS_PLAIN64.";
                     fsTypeName = QString("%1 (%2)").arg(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType)))
                             .arg(tr("AES Encryption"));
                 } else if (luksInfo.m_crypt == CRYPT_CIPHER::SM4_XTS_PLAIN64){
+                    qDebug() << "LUKS encryption is SM4_XTS_PLAIN64.";
                     fsTypeName = QString("%1 (%2)").arg(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType)))
                             .arg(tr("SM4 Encryption"));
                 }
             }
         } else {
+            qDebug() << "LUKS device is not decrypted, setting to EXT4.";
             fsTypeName = Utils::fileSystemTypeToString(FSType::FS_EXT4);
         }
     }
 
     if (-1 == fslist.indexOf(fsTypeName)) {
+        qDebug() << "File system type not in list, setting current text to ext4.";
         m_formatComboBox->setCurrentText("ext4");
     } else {
+        qDebug() << "File system type found in list, setting current text to:" << fsTypeName;
         m_formatComboBox->setCurrentText(fsTypeName);
     }
 
@@ -165,10 +179,12 @@ void FormateDialog::initUi()
     m_securityComboBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
 
     if ("SSD" == m_curDiskMediaType || DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Disk media type is SSD or current level is LOGICALVOLUME, adding Fast and Secure options.";
         QStringList securitylist;
         securitylist << tr("Fast") << tr("Secure");
         m_securityComboBox->addItems(securitylist);
     } else {
+        qDebug() << "Disk media type is not SSD and not logical volume, adding Fast, Secure, and Advanced options.";
         QStringList securitylist;
         securitylist << tr("Fast") << tr("Secure") << tr("Advanced");
         m_securityComboBox->addItems(securitylist);
@@ -311,6 +327,7 @@ void FormateDialog::initUi()
     m_failLabel->setText(tr("Failed to find the disk"));
 
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Current level is logical volume.";
         tipLabel->setText(tr("The action cannot be undone, please proceed with caution"));
         tipLabel->setFixedHeight(30);
         fileName->setText(tr("LV name:"));
@@ -350,6 +367,7 @@ void FormateDialog::initUi()
         QFontMetrics fm(formatName->font());
         updateEncryptionInfo(m_formatComboBox->currentText(), width() - fm.boundingRect(formatName->text()).width() - 40);
     }
+    qDebug() << "FormateDialog initialized.";
 }
 
 void FormateDialog::initConnection()
@@ -370,26 +388,33 @@ void FormateDialog::onTextChanged(const QString &text)
 {
     qDebug() << "Format name changed:" << text;
     if (!text.isEmpty()) {
+        qDebug() << "Format name is not empty.";
         QByteArray byteArray = text.toUtf8();
         if (m_formatComboBox->currentText().contains("fat32")) {
+            qDebug() << "File system type is fat32.";
             if (byteArray.size() > 11) {
+                qDebug() << "File system type is fat32, length exceeds the limit.";
                 m_fileNameEdit->setAlert(true);
                 m_fileNameEdit->showAlertMessage(tr("The length exceeds the limit"), -1);
 
                 m_warningButton->setEnabled(false);
             } else {
+                qDebug() << "File system type is fat32, length is within the limit.";
                 m_fileNameEdit->setAlert(false);
                 m_fileNameEdit->hideAlertMessage();
 
                 m_warningButton->setEnabled(true);
             }
         } else {
+            qDebug() << "File system type is not fat32.";
             if (byteArray.size() > 16) {
+                qDebug() << "File system type is not fat32, length exceeds the limit.";
                 m_fileNameEdit->setAlert(true);
                 m_fileNameEdit->showAlertMessage(tr("The length exceeds the limit"), -1);
 
                 m_warningButton->setEnabled(false);
             } else {
+                qDebug() << "File system type is not fat32, length is within the limit.";
                 m_fileNameEdit->setAlert(false);
                 m_fileNameEdit->hideAlertMessage();
 
@@ -397,6 +422,7 @@ void FormateDialog::onTextChanged(const QString &text)
             }
         }
     }
+    qDebug() << "Format name changed end.";
 }
 
 void FormateDialog::onComboxFormatTextChange(const QString &text)
@@ -553,6 +579,7 @@ void FormateDialog::onSecurityCurrentIndexChanged(int index)
             break;
         }
     }
+    qDebug() << "onSecurityCurrentIndexChanged completed.";
 }
 
 void FormateDialog::onWipingMethodCurrentIndexChanged(int index)
@@ -568,12 +595,14 @@ void FormateDialog::onWipingMethodCurrentIndexChanged(int index)
         break;
     }
     default:
+        qDebug() << "Unknown wiping method index:" << index;
         break;
     }
 }
 
 void FormateDialog::onCancelButtonClicked()
 {
+    qDebug() << "Cancel button clicked.";
     close();
 }
 
@@ -590,18 +619,23 @@ void FormateDialog::onWipeButtonClicked()
     CRYPT_CIPHER encryption = CRYPT_CIPHER::NOT_CRYPT;
     bool isEncryption = false;
     if (formate.contains("AES") || formate.contains("SM4")) {
+        qDebug() << "AES or SM4 encryption selected.";
         PasswordInputDialog passwordInputDialog(this);
         passwordInputDialog.setDeviceName(m_pathInfo);
         passwordInputDialog.setAccessibleName("passwordInputDialog");
         if (passwordInputDialog.exec() != DDialog::Accepted) {
+            qDebug() << "Password input dialog cancelled.";
             return;
         } else {
+            qDebug() << "Password input dialog accepted.";
             password = passwordInputDialog.getPassword();
             passwordHint = passwordInputDialog.getPasswordHint();
             if (formate.contains("AES")) {
+                qDebug() << "AES encryption selected.";
                 encryption = CRYPT_CIPHER::AES_XTS_PLAIN64;
                 encryptName = "aesE";
             } else if (formate.contains("SM4")) {
+                qDebug() << "SM4 encryption selected.";
                 encryption = CRYPT_CIPHER::SM4_XTS_PLAIN64;
                 encryptName = "sm4E";
             }
@@ -623,6 +657,7 @@ void FormateDialog::onWipeButtonClicked()
 
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION ||
             DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+        qDebug() << "Partition or disk wipe operation.";
         WipeAction wipe;
         wipe.m_fstype = formate;
         wipe.m_path = m_pathInfo;
@@ -632,32 +667,40 @@ void FormateDialog::onWipeButtonClicked()
         wipe.m_crypt = encryption;
         wipe.m_decryptStr = password;
         if (isEncryption) {
+            qDebug() << "Encryption enabled.";
             wipe.m_luksFlag = LUKSFlag::IS_CRYPT_LUKS;
             QStringList tokenList;
             if (!passwordHint.isEmpty()) {
+                qDebug() << "Password hint added.";
                 tokenList.append(passwordHint);
             }
 
             wipe.m_tokenList = tokenList;
             if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+                qDebug() << "Disk encryption selected.";
                 wipe.m_dmName = "";
             } else {
+                qDebug() << "Partition encryption selected.";
                 m_pathInfo == "unallocated" ? wipe.m_dmName = "" : wipe.m_dmName = QString("%1_%2").arg(m_pathInfo.remove("/dev/")).arg(encryptName);
             }
         } else {
+            qDebug() << "Encryption disabled.";
             wipe.m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
             wipe.m_tokenList = QStringList();
             wipe.m_dmName = "";
         }
 
         if (m_fileNameEdit->text().isEmpty()) {
+            qDebug() << "File system label not set.";
             wipe.m_fileSystemLabel  = " ";
             DMDbusHandler::instance()->clear(wipe);
         } else {
+            qDebug() << "File system label set.";
             wipe.m_fileSystemLabel  = m_fileNameEdit->text();
             DMDbusHandler::instance()->clear(wipe);
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Logical volume wipe operation.";
         LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
 
         LVAction lvAction;
@@ -671,15 +714,18 @@ void FormateDialog::onWipeButtonClicked()
         lvAction.m_crypt = encryption;
         lvAction.m_decryptStr = password;
         if (isEncryption) {
+            qDebug() << "Encryption enabled.";
             lvAction.m_luksFlag = LUKSFlag::IS_CRYPT_LUKS;
             QStringList tokenList;
             if (!passwordHint.isEmpty()) {
+                qDebug() << "Password hint added.";
                 tokenList.append(passwordHint);
             }
 
             lvAction.m_tokenList = tokenList;
             lvAction.m_dmName = QString("%1_%2_%3").arg(lvInfo.m_vgName).arg(lvInfo.m_lvName).arg(encryptName);
         } else {
+            qDebug() << "Encryption disabled.";
             lvAction.m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
             lvAction.m_tokenList = QStringList();
             lvAction.m_dmName = "";
@@ -693,11 +739,13 @@ void FormateDialog::onWipeButtonClicked()
     m_stackedWidget->setCurrentIndex(1);
     DWindowCloseButton *button = findChild<DWindowCloseButton *>("DTitlebarDWindowCloseButton");
     if (button != nullptr) {
+        qDebug() << "DWindowCloseButton found.";
         button->setDisabled(true);
         button->hide();
     }
 
     m_waterLoadingWidget->setStartTime(1000);
+    qDebug() << "Wiping operation started.";
 }
 
 void FormateDialog::onWipeResult(const QString &info)
@@ -706,16 +754,19 @@ void FormateDialog::onWipeResult(const QString &info)
     QStringList infoList = info.split(":");
 
     if (infoList.count() <= 2) {
+        qDebug() << "infoList count less than 2.";
         return;
     }
 
     m_waterLoadingWidget->stopTimer();
     bool isSuccess = false;
     if (infoList.at(0) == "DISK_ERROR" && infoList.at(1).toInt() == DISK_ERROR::DISK_ERR_NORMAL) {
+        qDebug() << "Wipe operation succeeded.";
         isSuccess = true;
     }
 
     if (isSuccess) {
+        qDebug() << "Wipe operation succeeded.";
         DMessageManager::instance()->sendMessage(this->parentWidget()->parentWidget()->parentWidget()->parentWidget(),
                                                  QIcon::fromTheme("://icons/deepin/builtin/ok.svg"),
                                                  tr("\"%1\" wiped").arg(m_pathInfo));
@@ -724,6 +775,7 @@ void FormateDialog::onWipeResult(const QString &info)
 
         close();
     } else {
+        qDebug() << "Wipe operation failed.";
         QString failedReason = DMDbusHandler::instance()->getFailedMessage(infoList.at(0), infoList.at(1).toInt(), "");
         setTitle(tr("Failed to wipe %1").arg(m_pathInfo));
         m_stackedWidget->setCurrentIndex(2);
@@ -734,5 +786,6 @@ void FormateDialog::onWipeResult(const QString &info)
 
         m_failLabel->setText(failedReason);
     }
+    qDebug() << "Wipe operation completed.";
 }
 
