@@ -27,11 +27,14 @@ PartitionTableErrorsInfoDialog::PartitionTableErrorsInfoDialog(const QString &de
     qDebug() << "Creating partition table errors dialog for device:" << deviceInfo;
     initUI();
     initConnections();
+    qDebug() << "PartitionTableErrorsInfoDialog constructor completed.";
 }
 
 PartitionTableErrorsInfoDialog::~PartitionTableErrorsInfoDialog()
 {
+    qDebug() << "PartitionTableErrorsInfoDialog destructor called.";
     delete m_partitionTableErrorsInfoDelegatee;
+    qDebug() << "PartitionTableErrorsInfoDialog destructor completed.";
 }
 
 void PartitionTableErrorsInfoDialog::initUI()
@@ -43,10 +46,12 @@ void PartitionTableErrorsInfoDialog::initUI()
 
     DPalette palette1;
     if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
+        qDebug() << "Theme is DarkType, setting palette color for dark theme.";
         QColor color("#FFFFFF");
         color.setAlphaF(0.7);
         palette1.setColor(DPalette::WindowText, color);
     } else if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
+        qDebug() << "Theme is LightType, setting palette color for light theme.";
         QColor color("#000000");
         color.setAlphaF(0.7);
         palette1.setColor(DPalette::WindowText, color);
@@ -84,8 +89,10 @@ void PartitionTableErrorsInfoDialog::initUI()
     m_partitionTableErrorsInfoDelegatee = new PartitionTableErrorsInfoDelegate(this);
     m_tableView->setItemDelegate(m_partitionTableErrorsInfoDelegatee);
     if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
+        qDebug() << "Theme is DarkType, setting delegate text color for dark theme.";
         m_partitionTableErrorsInfoDelegatee->setTextColor(QColor("#C0C6D4"));
     } else if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
+        qDebug() << "Theme is LightType, setting delegate text color for light theme.";
         m_partitionTableErrorsInfoDelegatee->setTextColor(QColor("#001A2E"));
     }
 
@@ -128,21 +135,27 @@ void PartitionTableErrorsInfoDialog::initUI()
     addContent(tableWidget);
     addSpacing(17);
     addContent(buttonWidget);
+    qDebug() << "Partition table errors UI initialization completed.";
 }
 
 void PartitionTableErrorsInfoDialog::initConnections()
 {
+    qDebug() << "Initializing PartitionTableErrorsInfoDialog connections.";
     connect(pushButton, &DPushButton::clicked, this, &PartitionTableErrorsInfoDialog::close);
+    qDebug() << "PartitionTableErrorsInfoDialog connections initialized.";
 }
 
 void PartitionTableErrorsInfoDialog::keyPressEvent(QKeyEvent *event)
 {
+    // qDebug() << "Key press event in PartitionTableErrorsInfoDialog, key:" << event->key();
     if (event->key() == Qt::Key::Key_Escape) {
         qDebug() << "Escape key pressed, ignoring";
         event->ignore();
     } else {
+        // qDebug() << "Other key pressed, calling DDialog::keyPressEvent.";
         DDialog::keyPressEvent(event);
     }
+    // qDebug() << "PartitionTableErrorsInfoDialog::keyPressEvent completed.";
 }
 
 
