@@ -30,6 +30,7 @@ TitleWidget::TitleWidget(DWidget *parent)
 
 void TitleWidget::initUi()
 {
+    qDebug() << "Initializing TitleWidget UI.";
     QHBoxLayout *layout = new QHBoxLayout(this);
 
     m_btnParted = createBtn(tr("Partition"), "partition");
@@ -102,21 +103,27 @@ void TitleWidget::initUi()
     m_btnResizeVG->hide();
 
     resetButtonsSize();
+    qDebug() << "TitleWidget UI initialization completed.";
 }
 
 void TitleWidget::setSizebyMode(DPushButton *button)
 {
+    qDebug() << "setSizebyMode called";
 #ifdef DTKWIDGET_CLASS_DSizeMode
+    qDebug() << "DTKWIDGET_CLASS_DSizeMode is defined, setting size by DSizeModeHelper.";
     button->setFixedSize(QSize(DSizeModeHelper::element(24, 36), DSizeModeHelper::element(24, 36)));
     button->setIconSize(QSize(DSizeModeHelper::element(12, 18), DSizeModeHelper::element(12, 18)));
 #else
+    qDebug() << "DTKWIDGET_CLASS_DSizeMode is not defined, setting fixed size (36x36) and icon size (18x18).";
     button->setFixedSize(QSize(36, 36));
     button->setIconSize(QSize(18, 18));
 #endif
+    qDebug() << "setSizebyMode completed.";
 }
 
 void TitleWidget::resetButtonsSize()
 {
+    qDebug() << "resetButtonsSize called.";
     setSizebyMode(m_btnCreateVG);
     setSizebyMode(m_btnParted);
     setSizebyMode(m_btnFormat);
@@ -129,10 +136,12 @@ void TitleWidget::resetButtonsSize()
     setSizebyMode(m_btnDeletePV);
     setSizebyMode(m_btnDeleteVG);
     setSizebyMode(m_btnDeleteLV);
+    qDebug() << "resetButtonsSize completed.";
 }
 
 void TitleWidget::initConnection()
 {
+    qDebug() << "Initializing TitleWidget connections.";
     connect(DMDbusHandler::instance(), &DMDbusHandler::curSelectChanged, this, &TitleWidget::onCurSelectChanged);
     connect(m_btnParted, &DPushButton::clicked, this, &TitleWidget::showPartInfoWidget);
     connect(m_btnFormat, &DPushButton::clicked, this, &TitleWidget::showFormateInfoWidget);
@@ -149,23 +158,29 @@ void TitleWidget::initConnection()
     connect(DMDbusHandler::instance(), &DMDbusHandler::updateUsb, this, &TitleWidget::onUpdateUsb);
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
+    qDebug() << "Connecting sizeModeChanged signal for DTKWIDGET_CLASS_DSizeMode.";
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [this]() {
         resetButtonsSize();
+        qDebug() << "Size mode changed, resetButtonsSize called.";
     });
 #endif
+    qDebug() << "TitleWidget connections initialized.";
 }
 
 DPushButton *TitleWidget::createBtn(const QString &btnName, const QString &objName, bool bCheckable)
 {
+    qDebug() << "createBtn called for btnName:" << btnName << ", objName:" << objName << ", bCheckable:" << bCheckable;
     auto btn = new DPushButton(this);
     //  wzx 设置图标icon    2020-05-19
     QIcon icon = Common::getIcon(objName);
 
     btn->setIcon(icon);
 #ifdef DTKWIDGET_CLASS_DSizeMode
+    qDebug() << "DTKWIDGET_CLASS_DSizeMode is defined, setting size by DSizeModeHelper.";
     btn->setFixedSize(QSize(DSizeModeHelper::element(24, 36), DSizeModeHelper::element(24, 36)));
     btn->setIconSize(QSize(DSizeModeHelper::element(12, 18), DSizeModeHelper::element(12, 18)));
 #else
+    qDebug() << "DTKWIDGET_CLASS_DSizeMode is not defined, setting fixed size (36x36) and icon size (18x18).";
     btn->setFixedSize(QSize(36, 36));
     btn->setIconSize(QSize(18, 18));
 #endif
@@ -175,9 +190,11 @@ DPushButton *TitleWidget::createBtn(const QString &btnName, const QString &objNa
     btn->setAccessibleName(objName);
 
     if (bCheckable) {
+        qDebug() << "Button is checkable, setting checked to false.";
         btn->setChecked(false);
     }
 
+    qDebug() << "createBtn completed, returning button:" << btn->objectName();
     return btn;
 }
 
@@ -192,7 +209,9 @@ void TitleWidget::showPartInfoWidget()
     setCurDevicePath(info.m_devicePath);
 
     if (dlg.exec() == 1) {
+        qDebug() << "PartitionDialog accepted.";
         if (TYPE_UNPARTITIONED == info.m_type && FS_UNALLOCATED == info.m_fileSystemType) {
+            qDebug() << "Device is unpartitioned and unallocated, showing warning.";
             setCurDevicePath("");
             qDebug() << QString("No partition table found on device %1").arg(info.m_devicePath);
             qDebug() << "A partition table is required before partitions can be added";
@@ -211,7 +230,10 @@ void TitleWidget::showPartInfoWidget()
         partitionWidget.exec();
 
         setCurDevicePath("");
+    } else {
+        qDebug() << "PartitionDialog rejected.";
     }
+    qDebug() << "showPartInfoWidget completed.";
 }
 
 void TitleWidget::showFormateInfoWidget()
@@ -229,20 +251,25 @@ void TitleWidget::showFormateInfoWidget()
 
 bool TitleWidget::showDecryptDialog()
 {
+    qDebug() << "Show decrypt dialog";
     DecryptDialog decryptDialog(this);
     decryptDialog.setObjectName("decryptDialog");
     decryptDialog.setAccessibleName("decryptDialog");
     if (decryptDialog.exec() != DDialog::Accepted) {
+        qDebug() << "Decrypt dialog not accepted.";
         return false;
     }
 
+    qDebug() << "Decrypt dialog accepted.";
     return true;
 }
 
 bool TitleWidget::showNoFileSystemWarningDialog(const LUKS_INFO &luksInfo)
 {
+    qDebug() << "Show no file system warning dialog";
     if (luksInfo.m_mapper.m_luksFs == FSType::FS_UNKNOWN || luksInfo.m_mapper.m_luksFs == FSType::FS_UNALLOCATED
             || luksInfo.m_mapper.m_luksFs == FSType::FS_UNSUPPORTED || luksInfo.m_mapper.m_luksFs == FSType::FS_UNFORMATTED) {
+        qDebug() << "No file system found, showing warning.";
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("partNoSupportFSWidget");
@@ -253,6 +280,7 @@ bool TitleWidget::showNoFileSystemWarningDialog(const LUKS_INFO &luksInfo)
         return true;
     }
 
+    qDebug() << "No file system warning dialog not shown.";
     return false;
 }
 
@@ -260,47 +288,56 @@ void TitleWidget::showMountInfoWidget()
 {
     qDebug() << "Show mount dialog";
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        qDebug() << "Current level is partition.";
         PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
         setCurDevicePath(info.m_devicePath);
         if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
             if (!showDecryptDialog()) {
                 setCurDevicePath("");
+                qDebug() << "Decrypt dialog not accepted, returning.";
                 return;
             }
 
             LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(info.m_path);
             if (showNoFileSystemWarningDialog(luksInfo)) {
                 setCurDevicePath("");
+                qDebug() << "No file system warning dialog shown, returning.";
                 return;
             }
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Current level is logical volume.";
         LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
         setCurVGName(lvInfo.m_vgName);
         if (lvInfo.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
             if (!showDecryptDialog()) {
                 setCurVGName("");
+                qDebug() << "Decrypt dialog not accepted, returning.";
                 return;
             }
 
             LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(lvInfo.m_lvPath);
             if (showNoFileSystemWarningDialog(luksInfo)) {
                 setCurVGName("");
+                qDebug() << "No file system warning dialog shown, returning.";
                 return;
             }
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+        qDebug() << "Current level is disk.";
         DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
         setCurDevicePath(info.m_path);
         if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
             if (!showDecryptDialog()) {
                 setCurDevicePath("");
+                qDebug() << "Decrypt dialog not accepted, returning.";
                 return;
             }
 
             LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(info.m_path);
             if (showNoFileSystemWarningDialog(luksInfo)) {
                 setCurDevicePath("");
+                qDebug() << "No file system warning dialog shown, returning.";
                 return;
             }
         }
@@ -312,8 +349,10 @@ void TitleWidget::showMountInfoWidget()
     dlg.exec();
 
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        qDebug() << "Current level is partition.";
         setCurDevicePath("");
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Current level is logical volume.";
         setCurVGName("");
     }
 }
@@ -322,8 +361,10 @@ void TitleWidget::showUnmountInfoWidget()
 {
     qDebug() << "Show unmount dialog";
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        qDebug() << "Current level is partition.";
         setCurDevicePath(DMDbusHandler::instance()->getCurPartititonInfo().m_devicePath);
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Current level is logical volume.";
         setCurVGName(DMDbusHandler::instance()->getCurLVInfo().m_vgName);
     }
 
@@ -333,8 +374,10 @@ void TitleWidget::showUnmountInfoWidget()
     dlg.exec();
 
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        qDebug() << "Current level is partition.";
         setCurDevicePath("");
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Current level is logical volume.";
         setCurVGName("");
     }
 }
@@ -346,6 +389,7 @@ void TitleWidget::showResizeInfoWidget()
     setCurDevicePath(info.m_devicePath);
     FS_Limits limits = info.m_fsLimits;
     if (limits.min_size == -1 && limits.max_size == -1) {
+        qDebug() << "Partition does not support resizing.";
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("partNoSupportFSWidget");
@@ -376,6 +420,7 @@ void TitleWidget::onCreateLVClicked()
     dlg.setAccessibleName("createLVDialog");
 
     if (dlg.exec() == 1) {
+        qDebug() << "Create LV dialog accepted.";
         CreateLVWidget createLVWidget(this);
         createLVWidget.setObjectName("createLVWidget");
         createLVWidget.setAccessibleName("createLVWidget");
@@ -392,6 +437,7 @@ void TitleWidget::onDeleteLVClicked()
     setCurVGName(lvInfo.m_vgName);
 
     if (DMDbusHandler::instance()->lvIsMount(lvInfo)) {
+        qDebug() << "LV is mounted.";
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("messageBox");
@@ -411,6 +457,7 @@ void TitleWidget::onDeleteLVClicked()
     messageBox.setWarings(tr("Data cannot be recovered if deleted, please confirm before proceeding"), "",
                           tr("Delete"), DDialog::ButtonWarning, "delete", tr("Cancel"), "cancel");
     if (messageBox.exec() == DDialog::Accepted) {
+        qDebug() << "Delete LV dialog accepted.";
         QStringList lvNameList;
         lvNameList << lvInfo.m_lvPath;
 
@@ -418,6 +465,7 @@ void TitleWidget::onDeleteLVClicked()
     }
 
     setCurVGName("");
+    qDebug() << "Delete LV dialog closed.";
 }
 
 void TitleWidget::onResizeLVClicked()
@@ -426,7 +474,9 @@ void TitleWidget::onResizeLVClicked()
     LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
     setCurVGName(lvInfo.m_vgName);
     if(lvInfo.m_lvFsType == FS_NTFS){
+        qDebug() << "LV is NTFS.";
         if (DMDbusHandler::instance()->lvIsMount(lvInfo)){
+            qDebug() << "LV is mounted.";
             MessageBox warningBox(this);
             warningBox.setObjectName("messageBox");
             warningBox.setAccessibleName("messageBox");
@@ -443,6 +493,7 @@ void TitleWidget::onResizeLVClicked()
     FS_Limits limits = lvInfo.m_fsLimits;
     if ((limits.min_size == -1 && limits.max_size == -1)
             || lvInfo.m_lvFsType == FS_FAT16 || lvInfo.m_lvFsType == FS_FAT32) { //fat32 or fat16 lvm情况下不支持调整
+        qDebug() << "LV does not support resizing.";
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("LVNoSupportFSWidget");
@@ -456,6 +507,7 @@ void TitleWidget::onResizeLVClicked()
     }
 
     if (lvInfo.m_fileSystemLabel == "Roota" || lvInfo.m_fileSystemLabel == "Rootb") {
+        qDebug() << "LV is Roota or Rootb.";
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("messageBox");
@@ -471,6 +523,7 @@ void TitleWidget::onResizeLVClicked()
     dlg.exec();
 
     setCurVGName("");
+    qDebug() << "Resize LV dialog closed.";
 }
 
 void TitleWidget::onCreateVGClicked()
@@ -482,6 +535,7 @@ void TitleWidget::onCreateVGClicked()
     dlg.setAccessibleName("createVGDialog");
 
     if (dlg.exec() == 1) {
+        qDebug() << "Create VG dialog accepted.";
         CreateVGWidget createVGWidget(CreateVGWidget::CREATE, this);
         createVGWidget.setObjectName("createVGWidget");
         createVGWidget.setAccessibleName("createVGWidget");
@@ -495,6 +549,7 @@ void TitleWidget::onDeleteVGClicked()
     VGInfo vgInfo = DMDbusHandler::instance()->getCurVGInfo();
     setCurVGName(vgInfo.m_vgName);
     if (DMDbusHandler::instance()->isExistMountLV(vgInfo)) {
+        qDebug() << "VG has mounted LV.";
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("messageBox");
@@ -514,6 +569,7 @@ void TitleWidget::onDeleteVGClicked()
     messageBox.setWarings(tr("Data cannot be recovered if deleted, please confirm before proceeding"), "",
                           tr("Delete"), DDialog::ButtonWarning, "delete", tr("Cancel"), "cancel");
     if (messageBox.exec() == DDialog::Accepted) {
+        qDebug() << "Delete VG dialog accepted.";
         QStringList vgNameList;
         vgNameList << vgInfo.m_vgName;
 
@@ -521,6 +577,7 @@ void TitleWidget::onDeleteVGClicked()
     }
 
     setCurVGName("");
+    qDebug() << "Delete VG dialog closed.";
 }
 
 void TitleWidget::onResizeVGClicked()
@@ -534,6 +591,7 @@ void TitleWidget::onResizeVGClicked()
     createVGWidget.exec();
 
     setCurVGName("");
+    qDebug() << "Resize VG dialog closed.";
 }
 
 void TitleWidget::onDeletePVClicked()
@@ -543,6 +601,7 @@ void TitleWidget::onDeletePVClicked()
     bool vgIsMount = false;
     QStringList lstVGName;
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        qDebug() << "Current level is partition.";
         PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
         setCurDevicePath(info.m_devicePath);
         VGData vgData = info.m_vgData;
@@ -560,6 +619,7 @@ void TitleWidget::onDeletePVClicked()
             }
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+        qDebug() << "Current level is disk.";
         DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
         setCurDevicePath(info.m_path);
         QStringList pvStrList;
@@ -605,11 +665,13 @@ void TitleWidget::onDeletePVClicked()
         }
 
         if (!lstVGName.isEmpty()) {
+            qDebug() << "VG has mounted LV.";
             vgIsMount = true;
         }
     }
 
     if (vgIsMount) {
+        qDebug() << "PV has mounted LV.";
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("deletePVMessageBox");
@@ -628,14 +690,18 @@ void TitleWidget::onDeletePVClicked()
     removePVWidget.exec();
 
     setCurDevicePath("");
+    qDebug() << "Delete PV dialog closed.";
 }
 
 void TitleWidget::updateBtnStatus()
 {
+    qDebug() << "Update button status.";
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        qDebug() << "Current level is partition.";
         updateBtnShowStatus(true, true, false, false, true, false, true, true);
         PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
         if (info.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV) {
+            qDebug() << "Partition is in PV.";
             m_btnParted->hide();
             m_btnCreateLV->show();
 
@@ -645,6 +711,7 @@ void TitleWidget::updateBtnStatus()
             m_btnCreateLV->setDisabled(true);
             updatePartitionBtnStatus(true, true, true, true, true);
         } else if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+            qDebug() << "Partition is in LUKS.";
             m_btnResize->setDisabled(true);
             m_btnDeletePV->setDisabled(true);
             m_btnParted->setDisabled(true);
@@ -652,19 +719,23 @@ void TitleWidget::updateBtnStatus()
             LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(info.m_path);
             updateEncryptDeviceBtnStatus(luksInfo);
         } else {
+            qDebug() << "Partition is not in PV or LUKS.";
             m_btnDeletePV->setDisabled(true);
             m_btnParted->show();
             m_btnCreateLV->hide();
 
             //已挂载
             if (info.m_mountPoints.size() > 0 && info.m_busy) {
+                qDebug() << "Partition is mounted.";
                 updatePartitionBtnStatus(true, true, true, false, true);
 
                 if (1 == info.m_flag) {
                     m_btnUnmount->setDisabled(true);
                 }
             } else {
+                qDebug() << "Partition is not mounted.";
                 if (1 == info.m_flag) {
+                    qDebug() << "Partition is not mounted.";
                     updatePartitionBtnStatus(true, true, true, true, true);
                 } else {
                     //需判断扩展分区上是否无分区，否则认为不可操作，此处省略操作
@@ -685,19 +756,23 @@ void TitleWidget::updateBtnStatus()
 
             qDebug() << info.m_type << info.m_fileSystemType;
             if (info.m_fileSystemType == FSType::FS_LINUX_SWAP) {
+                qDebug() << "Partition is swap.";
                 updatePartitionBtnStatus(true, true, true, true, true);
             }
             //CD,DVD disable format
             if (info.m_devicePath.startsWith("/dev/sr") || info.m_devicePath.startsWith("/dev/cdrom")) {
+                qDebug() << "Partition is CD or DVD.";
                 updatePartitionBtnStatus(true, true, true, true, true);
             }
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+        qDebug() << "Current level is disk.";
         updateBtnShowStatus(true, true, false, false, true, false, true, true);
         updatePartitionBtnStatus(true, true, true, true, true);
 
         DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
         if (info.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV) { //有分区创建为pv
+            qDebug() << "Disk is in PV.";
             m_btnParted->hide();
             m_btnCreateLV->show();
 
@@ -715,6 +790,7 @@ void TitleWidget::updateBtnStatus()
             m_btnCreateLV->setDisabled(true);
             m_btnFormat->setDisabled(true);
         } else if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS && info.m_partition.size() == 0) {
+            qDebug() << "Disk is in LUKS.";
             LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(info.m_path);
             m_btnDeletePV->setDisabled(true);
             if (luksInfo.isDecrypt) {
@@ -727,6 +803,7 @@ void TitleWidget::updateBtnStatus()
                 updatePartitionBtnStatus(true, false, false, true, true);
             }
         } else {
+            qDebug() << "Disk is not in PV or LUKS.";
             m_btnParted->show();
             m_btnCreateLV->hide();
 
@@ -741,6 +818,7 @@ void TitleWidget::updateBtnStatus()
             }
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::VOLUMEGROUP) {
+        qDebug() << "Current level is VG.";
         updateBtnShowStatus(false, true, true, true, false, true, false, true);
 
         // 如果VG异常，所有相关操作禁用
@@ -757,17 +835,20 @@ void TitleWidget::updateBtnStatus()
             m_btnCreateLV->setDisabled(true);
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
+        qDebug() << "Current level is LV.";
         updateBtnShowStatus(true, false, true, true, false, true, true, false);
 
         // 如果VG异常，所有相关操作禁用
         VGInfo vgInfo = DMDbusHandler::instance()->getCurVGInfo();
         if (vgInfo.isPartial()) {
+            qDebug() << "VG is partial.";
             updateLVBtnStatus(true, true, true, true, true, true);
             return;
         }
 
         LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
         if (lvInfo.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+            qDebug() << "LV is in LUKS.";
             m_btnResizeLV->setDisabled(true);
             m_btnCreateLV->setDisabled(true);
 
@@ -777,19 +858,24 @@ void TitleWidget::updateBtnStatus()
         }
 
         if (lvInfo.m_lvName.isEmpty() && lvInfo.m_lvUuid.isEmpty()) {
+            qDebug() << "LV is not exist.";
             updateLVBtnStatus(true, false, true, true, true, true);
         } else if (lvInfo.m_lvFsType == FSType::FS_LINUX_SWAP) {
+            qDebug() << "LV is swap.";
             updateLVBtnStatus(true, true, true, true, true, false);
         } else {
+            qDebug() << "LV is not swap.";
             bool noMountPoint = lvInfo.m_mountPoints.isEmpty();
             updateLVBtnStatus(false, true, !noMountPoint, !noMountPoint, noMountPoint, false);
         }
     }
+    qDebug() << "TitleWidget::updateLVBtnStatus completed.";
 }
 
 void TitleWidget::updatePartitionBtnStatus(const bool &isCreate, const bool &isWipe, const bool &isMount,
                                            const bool &isUnmount, const bool &isResize)
 {
+    qDebug() << "Update partition button status.";
     m_btnParted->setDisabled(isCreate);
     m_btnFormat->setDisabled(isWipe);
     m_btnMount->setDisabled(isMount);
@@ -800,6 +886,7 @@ void TitleWidget::updatePartitionBtnStatus(const bool &isCreate, const bool &isW
 void TitleWidget::updateVGBtnStatus(const bool &isDeleteVG, const bool &isCreateLV, const bool &isWipe,
                                     const bool &isMount, const bool &isUnmount, const bool &isResize)
 {
+    qDebug() << "Update VG button status.";
     m_btnDeleteVG->setDisabled(isDeleteVG);
     m_btnCreateLV->setDisabled(isCreateLV);
     m_btnFormat->setDisabled(isWipe);
@@ -811,6 +898,7 @@ void TitleWidget::updateVGBtnStatus(const bool &isDeleteVG, const bool &isCreate
 void TitleWidget::updateLVBtnStatus(const bool &isDeleteLV, const bool &isCreateLV, const bool &isWipe,
                        const bool &isMount, const bool &isUnmount, const bool &isResize)
 {
+    qDebug() << "Update LV button status.";
     m_btnDeleteLV->setDisabled(isDeleteLV);
     m_btnCreateLV->setDisabled(isCreateLV);
     m_btnFormat->setDisabled(isWipe);
@@ -823,6 +911,7 @@ void TitleWidget::updateBtnShowStatus(const bool &isDeleteVGShow, const bool &is
                                       const bool &isPartedShow, const bool &isCreateLVShow, const bool &isResizShow,
                                       const bool &isResizeVGShow, const bool &isResizeLVShow)
 {
+    qDebug() << "Update button show status.";
     m_btnDeleteVG->setHidden(isDeleteVGShow);
     m_btnDeleteLV->setHidden(isDeleteLVShow);
     m_btnDeletePV->setHidden(isDeletePVShow);
@@ -835,21 +924,27 @@ void TitleWidget::updateBtnShowStatus(const bool &isDeleteVGShow, const bool &is
 
 void TitleWidget::updateEncryptDeviceBtnStatus(const LUKS_INFO &luksInfo)
 {
+    qDebug() << "Update encrypt device button status.";
     if (luksInfo.isDecrypt) {
+        qDebug() << "Device is decrypt.";
         if (luksInfo.m_mapper.m_luksFs == FSType::FS_LVM2_PV) {
+            qDebug() << "Device is PV.";
             m_btnFormat->setDisabled(true);
             m_btnMount->setDisabled(true);
             m_btnUnmount->setDisabled(true);
         } else if (luksInfo.m_mapper.m_mountPoints.isEmpty()) {
+            qDebug() << "Device is not mount.";
             m_btnFormat->setDisabled(false);
             m_btnMount->setDisabled(false);
             m_btnUnmount->setDisabled(true);
         } else {
+            qDebug() << "Device is mount.";
             m_btnFormat->setDisabled(true);
             m_btnMount->setDisabled(true);
             m_btnUnmount->setDisabled(false);
         }
     } else {
+        qDebug() << "Device is not decrypt.";
         m_btnFormat->setDisabled(false);
         m_btnMount->setDisabled(false);
         m_btnUnmount->setDisabled(true);
@@ -858,20 +953,26 @@ void TitleWidget::updateEncryptDeviceBtnStatus(const LUKS_INFO &luksInfo)
 
 void TitleWidget::onCurSelectChanged()
 {
+    qDebug() << "TitleWidget::onCurSelectChanged";
     updateBtnStatus();
     qDebug() << "Current selection changed";
 }
 
 void TitleWidget::onUpdateUsb()
 {
+    qDebug() << "TitleWidget::onUpdateUsb";
     if (m_curChooseDevicePath.isEmpty() && m_curChooseVGName.isEmpty()) {
+        qDebug() << "No device or VG selected.";
         return;
     }
 
     if (!m_curChooseDevicePath.isEmpty()) {
+        qDebug() << "Update device: " << m_curChooseDevicePath;
         QStringList deviceNameList = DMDbusHandler::instance()->getDeviceNameList();
-        if (deviceNameList.indexOf(m_curChooseDevicePath) != -1)
+        if (deviceNameList.indexOf(m_curChooseDevicePath) != -1) {
+            qDebug() << "Device is already in list.";
             return;
+        }
 
         QWidgetList widgetList = QApplication::topLevelWidgets();
         for (int i = 0; i < widgetList.count(); i++) {
@@ -892,9 +993,12 @@ void TitleWidget::onUpdateUsb()
 
         setCurDevicePath("");
     } else if (!m_curChooseVGName.isEmpty()) {
+        qDebug() << "Update VG: " << m_curChooseVGName;
         QStringList vgNameList = DMDbusHandler::instance()->getVGNameList();
-        if (vgNameList.indexOf(m_curChooseVGName) != -1)
+        if (vgNameList.indexOf(m_curChooseVGName) != -1) {
+            qDebug() << "VG is already in list.";
             return;
+        }
 
         QWidgetList widgetList = QApplication::topLevelWidgets();
         for (int i = 0; i < widgetList.count(); i++) {
@@ -909,21 +1013,25 @@ void TitleWidget::onUpdateUsb()
 
         setCurVGName("");
     }
+    qDebug() << "Update VG completed.";
 }
 
 void TitleWidget::setCurDevicePath(const QString &devPath)
 {
+    qDebug() << "TitleWidget::setCurDevicePath";
     m_curChooseDevicePath = devPath;
 }
 
 void TitleWidget::setCurVGName(const QString &vgName)
 {
+    qDebug() << "TitleWidget::setCurVGName";
     m_curChooseVGName = vgName;
 }
 
 void TitleWidget::mousePressEvent(QMouseEvent *event)
 {
     if (event->button() == Qt::RightButton) {
+        qDebug() << "TitleWidget::mousePressEvent";
         return;
     }
 
