@@ -142,14 +142,17 @@ bool DeviceStorage::addInfoFromlshw(const QMap<QString, QString> &mapInfo)
         qWarning() << "Invalid bus info format:" << mapInfo["bus info"];
         return false;
     }
-    QString key = keys[1].trimmed();
-    key.replace(".", ":");
-    if (key != m_KeyToLshw) {
-        qDebug() << "lshw key does not match, returning false";
-        return false;
+    if (keys[0].trimmed() == "nvme") {
+        qDebug() << "nvme device found, not check KeyToLshw";
+    } else {
+        QString key = keys[1].trimmed();
+        key.replace(".", ":");
+        if (key != m_KeyToLshw) {
+            qDebug() << "lshw key does not match, returning false" << keys[0].trimmed() << key << m_KeyToLshw;
+            return false;
+        }
     }
 
-
     // 获取唯一key
     QStringList words = mapInfo["bus info"].split(":");
     if (words.size() == 2) {
@@ -242,7 +245,7 @@ void DeviceStorage::getInfoFromLshw(const QMap<QString, QString> &mapInfo)
     QRegularExpressionMatch match = re.match(m_size);
     if (match.hasMatch()) {
         qDebug() << "Size match found in lshw info";
-        m_interface = match.captured(1);
+        m_size = match.captured(1);
     }
 #else
     QRegExp re(".*\\((.*)\\)$");
@@ -353,10 +356,12 @@ bool DeviceStorage::getDiskInfoFromHwinfo(const QString &devicePath)
 {
     qDebug() << "Getting disk info from hwinfo for device:" << devicePath;
     QString cmd = QString("hwinfo --disk --only %1").arg(devicePath);
-    QProcess proc;
-    proc.start(cmd);
-    proc.waitForFinished(-1);
-    QString outPut = proc.readAllStandardOutput();
+    QString outPut;
+    QString error;
+    if (Utils::executCmd(cmd, outPut, error) != 0) {
+        qDebug() << "Failed to execute hwinfo command, error:" << error;
+        return false;
+    }
 
     QMap<QString, QString> mapInfo;
 
@@ -440,31 +445,31 @@ void DeviceStorage::getMapInfoFromInput(const QString &info, QMap<QString, QStri
 bool DeviceStorage::getDiskInfoFromLshw(const QString &devicePath)
 {
     qDebug() << "DeviceStorage::getDiskInfoFromLshw BEGIN";
-    QProcess proc;
-    proc.start("sudo lshw -C disk");
-    proc.waitForFinished(-1);
-    QString outPut  = proc.readAllStandardOutput();
-
-    QStringList list = outPut.split("*-disk\n");
-
-    outPut.clear();
-    for (int i =0;i<list.count();i++) {
-        if(list.at(i).contains(devicePath)) {
-            qDebug() << "devicePath found in lshw output";
-            outPut = list.at(i);
-            break;
-        }
+    QString outPut, error;
+    if (Utils::executCmd("lshw -C disk", outPut, error) != 0) {
+        qDebug() << "Failed to execute lshw command, error:" << error;
+        return false;
     }
 
-    if (outPut.isEmpty()) {
+    QString diskInfo;
+    QStringList list = outPut.split("*-disk");
+    foreach (const QString &item, list) {
+        QStringList list2 = item.split("*-namespace");
+        foreach (const QString &item2, list2) {
+            if (item2.contains(devicePath)) {
+                qDebug() << "devicePath found in lshw output";
+                diskInfo = item2;
+                break;
+            }
+        }
+    }
+    if (diskInfo.isEmpty()) {
         qDebug() << "devicePath not found in lshw output, return false";
         return false;
     }
 
     QMap<QString, QString> mapInfo;
-
-    getMapInfoFromLshw(outPut, mapInfo);
-
+    getMapInfoFromLshw(diskInfo, mapInfo);
     addInfoFromlshw(mapInfo);
 
     qDebug() << "DeviceStorage::getDiskInfoFromLshw END";
@@ -523,12 +528,13 @@ bool DeviceStorage::getDiskInfoFromLsblk(const QString &devicePath)
 {
     qDebug() << "DeviceStorage::getDiskInfoFromLsblk BEGIN";
     QString cmd = QString("lsblk -d -o name,rota %1").arg(devicePath);
-    QProcess proc;
-    proc.start(cmd);
-    proc.waitForFinished(-1);
+    QString outPut, error;
+    if (Utils::executCmd(cmd, outPut, error) != 0) {
+        qDebug() << "Failed to execute lsblk command, error:" << error;
+        return false;
+    }
 
     QMap<QString, QString> mapInfo;
-    QString outPut = proc.readAllStandardOutput();
 
     loadLsblkInfo(outPut, mapInfo);
 
@@ -568,18 +574,18 @@ bool DeviceStorage::getDiskInfoFromSmartCtl(const QString &devicePath)
 {
     qDebug() << "DeviceStorage::getDiskInfoFromSmartCtl BEGIN";
     QString cmd = QString("smartctl --all %1").arg(devicePath);
-    QProcess proc;
-    proc.start(cmd);
-    proc.waitForFinished(-1);
-    QString outPut  = proc.readAllStandardOutput();
+    QString outPut, error;
+    int exitcode = Utils::executCmd(cmd, outPut, error);
 
     if (outPut.contains("Please specify device type with the -d option")) {
         qDebug() << "need to specify device type";
-        QString cmd = QString("smartctl --all -d sat %1").arg(devicePath);
-        QProcess proc;
-        proc.start(cmd);
-        proc.waitForFinished(-1);
-        outPut = proc.readAllStandardOutput();
+        cmd = QString("smartctl --all -d sat %1").arg(devicePath);
+        exitcode = Utils::executCmd(cmd, outPut, error);
+    }
+
+    if (exitcode != 0) {
+        qDebug() << "Failed to execute smartctl command, error:" << error;
+        return false;
     }
 
     QMap<QString, QString> mapInfo;
@@ -595,18 +601,19 @@ bool DeviceStorage::getDiskInfoFromSmartCtl(const QString &devicePath)
 void DeviceStorage::getDiskInfoModel(const QString &devicePath, QString &model)
 {
     qDebug() << "DeviceStorage::getDiskInfoModel BEGIN";
-    QProcess proc;
     QString cmd = QString("smartctl --all %1").arg(devicePath);
-    proc.start(cmd);
-    proc.waitForFinished(-1);
-    QString outPut = proc.readAllStandardOutput();
+    QString outPut, error;
+    int exitcode = Utils::executCmd(cmd, outPut, error);
 
     if (outPut.contains("Please specify device type with the -d option")) {
         qDebug() << "need to specify device type";
         cmd = QString("smartctl --all -d sat %1").arg(devicePath);
-        proc.start(cmd);
-        proc.waitForFinished(-1);
-        outPut = proc.readAllStandardOutput();
+        exitcode = Utils::executCmd(cmd, outPut, error);
+    }
+
+    if (exitcode != 0) {
+        qDebug() << "Failed to execute smartctl command, error:" << error;
+        return;
     }
 
     QStringList infoList = outPut.split("\n");
@@ -620,9 +627,11 @@ void DeviceStorage::getDiskInfoModel(const QString &devicePath, QString &model)
     }
 
     cmd = "lshw -C disk";
-    proc.start(cmd);
-    proc.waitForFinished(-1);
-    outPut = proc.readAllStandardOutput();
+    exitcode = Utils::executCmd(cmd, outPut, error);
+    if (exitcode != 0) {
+        qDebug() << "Failed to execute lshw command, error:" << error;
+        return;
+    }
 
     infoList = outPut.split("*-disk\n");
     for (int i =0; i < infoList.size(); i++) {
@@ -650,21 +659,19 @@ QString DeviceStorage::getDiskInfoMediaType(const QString &devicePath)
 {
     qDebug() << "DeviceStorage::getDiskInfoMediaType BEGIN";
     QStringList deviceList = devicePath.split("/");
+    if (deviceList.size() < 2) {
+        qDebug() << "deviceList.size() < 2, return UnKnow";
+        return "UnKnow";
+    }
     QString device = deviceList[deviceList.size()-1];
-    QString value;
-    QString cmd = QString("cat /sys/block/%1/queue/rotational").arg(device);
-    QProcess proc;
-    proc.start(cmd);
-    proc.waitForFinished(-1);
-    QString outPut = proc.readAllStandardOutput().trimmed();
-    value = outPut;
+    QString rotational_file = QString("/sys/block/%1/queue/rotational").arg(device);
+    QString value = Utils::readContent(rotational_file).trimmed();
 
     if ("1" == value) {
         qDebug() << "value is 1";
-        cmd = QString("smartctl -i %1").arg(devicePath);
-        proc.start(cmd);
-        proc.waitForFinished(-1);
-        outPut = proc.readAllStandardOutput();
+        QString cmd = QString("smartctl -i %1").arg(devicePath);
+        QString outPut, error;
+        int exitcode = Utils::executCmd(cmd, outPut, error);
         if (outPut.contains("Solid State Device")) {
             qDebug() << "is Solid State Device";
             value = "0";
@@ -672,15 +679,12 @@ QString DeviceStorage::getDiskInfoMediaType(const QString &devicePath)
             qDebug() << "need to specify device type";
             //FIXME: Hard type scsi for USB disk
             cmd = QString("smartctl -i -d scsi %1").arg(devicePath);
-            proc.start(cmd);
-            proc.waitForFinished(-1);
-            outPut = proc.readAllStandardOutput();
+            exitcode = Utils::executCmd(cmd, outPut, error);
             if (!outPut.contains("Rotation Rate:")) {
                 qDebug() << "not contains Rotation Rate";
                 value = "0";
             }
         }
-
     }
     if (QString("0") == value) {
         qDebug() << "return SSD";
@@ -734,10 +738,13 @@ void DeviceStorage::getDiskInfoInterface(const QString &devicePath, QString &int
     if (interface.isEmpty()) {
         qDebug() << "interface is empty";
         QString cmd = QString("hwinfo --disk --only %1").arg(devicePath);
-        QProcess proc;
-        proc.start(cmd);
-        proc.waitForFinished(-1);
-        QString outPut = proc.readAllStandardOutput().trimmed();
+        QString outPut, error;
+        int exitcode = Utils::executCmd(cmd, outPut, error);
+        if (exitcode != 0) {
+            interface = "UnKnow";
+            qDebug() << "Failed to execute hwinfo command, error:" << error;
+            return;
+        }
         QStringList outPutList = outPut.split("(");
         interface = outPutList[outPutList.size() - 1].split(" ")[0];
     }
@@ -792,7 +799,7 @@ void DeviceStorage::getMapInfoFromSmartctl(QMap<QString, QString> &mapInfo, cons
         int index = line.indexOf(ch);
 #if QT_VERSION_MAJOR > 5
         QRegularExpressionMatch match = reg.match(line);
-        if (index > 0 && !match.hasMatch() && match.captured(0) == line && false == line.contains("Error") && false == line.contains("hh:mm:SS")) {
+        if (index > 0 && !match.hasMatch() && false == line.contains("Error") && false == line.contains("hh:mm:SS")) {
 #else
         if (index > 0 && reg.exactMatch(line) == false && false == line.contains("Error") && false == line.contains("hh:mm:SS")) {
 #endif
